@@ -13,10 +13,10 @@ class Content_Sql_Pdo_PgsqlTest extends Content_Test_Sql_Base
             self::$reason = 'No pgsql extension or no pgsql PDO driver';
             return;
         }
-        $config = self::getConfig('GROUP_SQL_PDO_PGSQL_TEST_CONFIG',
+        $config = self::getConfig('CONTENT_SQL_PDO_PGSQL_TEST_CONFIG',
                                   __DIR__ . '/../..');
-        if ($config && !empty($config['group']['sql']['pdo_pgsql'])) {
-            self::$db = new Horde_Db_Adapter_Pdo_Pgsql($config['group']['sql']['pdo_pgsql']);
+        if ($config && !empty($config['content']['sql']['pdo_pgsql'])) {
+            self::$db = new Horde_Db_Adapter_Pdo_Pgsql($config['content']['sql']['pdo_pgsql']);
             parent::setUpBeforeClass();
         }
     }
